# generativepy

Generative art and graphing library for creating images and animations.

## Usage

generativepy is a library rather an application. It provides useful functions and example code that allow you to
create images and videos by writing simple Python scripts.

The library uses [pycairo](https://pycairo.readthedocs.io/en/latest/index.html) for drawing graphics.

Main functionality:

* A simple framework for creating images, image sequences, and gifs, using pycairo.
* Support for bitmap processing using PIL and NumPy.
* Colour module that supports RGB, HSL and CSS colours, transparency, lerping, colormaps.
* A simple tweening module to help with animation.
* Geometry module for drawing shapes.
* A graphing library for plotting 2D functions.

## Website

Visit [tenminutetutor.com](http://www.tenminutetutor.com/generative-art/generativepy/) for details:

* [generativepy reference](http://www.tenminutetutor.com/generative-art/generativepy/).
* [generativepy tutorials](http://www.tenminutetutor.com/generative-art/generativepy-tutorial/).
* [Generative art examples](http://www.tenminutetutor.com/generative-art/generativepy-art/).

For detailed information of pycairo see the [Computer graphics in Python](https://leanpub.com/computergraphicsinpython) ebook.
